/*
 * Qt5-UKUI's Library
 *
 * Copyright (C) 2023, KylinSoft Co., Ltd.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this library.  If not, see <https://www.gnu.org/licenses/>.
 *
 * Authors: Jing Tan <tanjing@kylinos.cn>
 *
 */

import QtQuick 2.12
import QtQuick.Templates 2.12 as T
import QtQuick.Controls 2.12
import QtQuick.Controls.impl 2.12
import org.ukui.qqc2style.private 1.0 as StylePrivate

T.ProgressBar {
    id: control

    implicitWidth: Math.max(implicitBackgroundWidth + leftInset + rightInset,
                            implicitContentWidth + leftPadding + rightPadding)
    implicitHeight: Math.max(implicitBackgroundHeight + topInset + bottomInset,
                             implicitContentHeight + topPadding + bottomPadding)

    ParseInterface{
        id: parseInterface
    }

    function getStartColor(dtcolor)
    {
        return parseInterface.pStartColor(dtcolor)
    }
    function getEndColor(dtcolor)
    {
        return parseInterface.pEndColor(dtcolor)
    }

    background: Rectangle {
        radius: progressbar.radius
        implicitWidth: progressbar.normalWidth
        implicitHeight: progressbar.normalHeight

        height: progressbar.normalHeight

        color: gradientRec.visible ? "transparent" : getStartColor(progressbar.normalColor)
        border.width: progressbar.borderWidth
        border.color: getStartColor(progressbar.borderColor)

        Rectangle{
            id: gradientRec
            anchors.fill: parent
            radius: parent.radius
            border.width: parent.border.width
            border.color: parent.border.color
            gradient:  Gradient {
                GradientStop { position: 0.0; color: getStartColor(progressbar.normalColor) }

                GradientStop { position: 1.0; color: getEndColor(progressbar.normalColor)}
            }
            visible: !parseInterface.isSolidPattern(progressbar.normalColor)
        }


    }

    contentItem: Item{
        implicitHeight: background.height
        implicitWidth: background.width
        Rectangle {
            x: !control.mirrored ? 0 : (control.width * (1.0 - control.position))
            implicitHeight: progressbar.normalHeight
            implicitWidth: control.width * control.position
            visible: !control.indeterminate
            //indeterminate: control.visible && control.indeterminate
            color: gradientItem.visible ? "transparent" : getStartColor(progressbar.childrenColor)
            radius: progressbar.radius

            Rectangle{
                id: gradientItem
                anchors.fill: parent
                radius: parent.radius
                border.width: parent.border.width
                border.color: parent.border.color
                gradient:  Gradient {
                    GradientStop { position: 0.0; color: getStartColor(progressbar.childrenColor) }

                    GradientStop { position: 1.0; color: getEndColor(progressbar.childrenColor)}
                }
                visible: !parseInterface.isSolidPattern(progressbar.childrenColor)
            }
        }
        Label{
            visible: !control.indeterminate
            anchors.centerIn: parent
            text: (control.position * 100).toString() + "%"
            color: control.value > (control.from + (control.to - control.from) * 1.0 / 2.0 ) ? getStartColor(progressbar.hightlightTextColor) :
                                                                                             getStartColor(StylePrivate.UKUILabel.normalColor)
        }
        Rectangle {
            id:rec
            implicitHeight: progressbar.normalHeight
            implicitWidth: progressbar.indeterminateChildrenWidth
            visible: control.indeterminate
            //indeterminate: control.visible && control.indeterminate
            color: gradientInterminate.visible ? "transparent" : getStartColor(progressbar.childrenColor)
            radius: progressbar.radius

            Rectangle{
                id: gradientInterminate
                anchors.fill: parent
                radius: parent.radius
                border.width: parent.border.width
                border.color: parent.border.color
                gradient:  Gradient {
                    GradientStop { position: 0.0; color: getStartColor(progressbar.childrenColor) }

                    GradientStop { position: 1.0; color: getEndColor(progressbar.childrenColor)}
                }
                visible: !parseInterface.isSolidPattern(progressbar.childrenColor)
            }
        }

        Timer {
            id: slideTimer
            interval: 1
            running: control.indeterminate
            repeat: true
            onTriggered: {
                slideAnimation.start()
            }
        }

        PropertyAnimation {
            id: slideAnimation
            target: rec
            property: "x"
            to: rec.x + rec.width >= control.width ? 0 : control.width - rec.width
            duration: 500 + control.width
            easing.type: Easing.InOutQuad
        }
    }


    StylePrivate.UKUIProgressBar{
        id: progressbar
    }

    StylePrivate.APPParameter{
        id: app
    }
}
